#!/bin/bash
COLUMNS=$(tput cols)
RUNS=1

TOOL=../adam.jar

# Philosophers
NAME=PH_G
START=2
END=10
mkdir -p $NAME
echo "-------------------- Philosophers (guided) ------------------------------"
for (( i=START; i<=END; i++)) do
	FILE=$NAME/$i"_"$NAME
	echo "Generate "$(($i - $START + 1))"/"$(($END - $START+1))
	java -jar $TOOL gen_phil -o $FILE -p $i

	echo  'Calculate '$FILE
	printf "%*s\r" $COLUMNS "(=0%)"
	for ((j=1; j<=RUNS; j++)) do
		val=""		
		para=""
		if [ $j == 1 ]; then
			val=$FILE"_sizes.txt"
			para=-ob
			echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
		fi
		/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
		rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
		echo -ne ' ('=$(( $j * 100 / $RUNS))'%) \r'
		printf "%*s\r" $COLUMNS " (=$(( $j * 100 / $RUNS))%)"
	done
done

NAME=PH
START=2
END=6
mkdir -p $NAME
echo "-------------------- Philosophers (non guided) ------------------------------"
for (( i=START; i<=END; i++)) do
	FILE=$NAME/$i"_"$NAME
	echo "Generate "$(($i - $START + 1))"/"$(($END - $START+1))
	java -jar $TOOL gen_phil -o $FILE -ng -p $i

	echo  'Calculate '$FILE
	printf "%*s\r" $COLUMNS "(=0%)"
	for ((j=1; j<=RUNS; j++)) do
		val=""		
		para=""
		if [ $j == 1 ]; then
			val=$FILE"_sizes.txt"
			para=-ob
			echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
		fi
		/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
		rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
#		echo -ne ' ('=$(( $j * 100 / $RUNS))'%) \r'
		printf "%*s\r" $COLUMNS " (=$(( $j * 100 / $RUNS))%)"
	done
done

# Workflow2 (CM)
NAME=CM
START=2
END=6
START_DISTR=1
END_DISTR=6
mkdir -p $NAME
echo "-------------------- workflow 2 (CM) ------------------------------"
for (( i=START; i<=END; i++)) do
	for ((k=START_DISTR; k<= END_DISTR; k++)) do
		FILE=$NAME/"m"$i"_w"$k"_"$NAME
		java -jar $TOOL gen_workflow2 -m $i -w $k -o $FILE

		echo  'Calculate '$FILE	
		printf "%*s\r" $COLUMNS "(=0%)"
		for ((j=1; j<=RUNS; j++)) do
			val=""		
			para=""
			if [ $j == 1 ]; then
				val=$FILE"_sizes.txt"
				para=-ob
				echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
			fi
			/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
			rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
		done
	done
done

# Self-organizing robots (SR)
NAME=SR
START=2
END=3
START_DISTR=1
END_DISTR=4
mkdir -p $NAME
echo "-------------------- Self-organizing robots (SR) ------------------------------"
for (( i=START; i<=END; i++)) do
	for ((k=START_DISTR; k<= END_DISTR; k++)) do
		FILE=$NAME/"r"$i"_d"$k"_"$NAME
		java -jar $TOOL gen_robots -r $i -d $k -o $FILE

		echo  'Calculate '$FILE	
		printf "%*s\r" $COLUMNS "(=0%)"
		for ((j=1; j<=RUNS; j++)) do
			val=""		
			para=""
			if [ $j == 1 ]; then
				val=$FILE"_sizes.txt"
				para=-ob
				echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
			fi
			/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
			rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
		done
	done
done

# Workflow (JP)
NAME=JP
START=2
END=11
mkdir -p $NAME
echo "-------------------- Workflow (JP) ------------------------------"
for (( i=START; i<=END; i++)) do
	FILE=$NAME/$i"_"$NAME
	echo "Generate "$(($i - $START + 1))"/"$(($END - $START+1))
	java -jar $TOOL gen_workflow -m $i -o $FILE

	echo  'Calculate '$FILE
	printf "%*s\r" $COLUMNS "(=0%)"
	for ((j=1; j<=RUNS; j++)) do
		val=""		
		para=""
		if [ $j == 1 ]; then
			val=$FILE"_sizes.txt"
			para=-ob
			echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
		fi
		/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
		rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
		printf "%*s\r" $COLUMNS " (=$(( $j * 100 / $RUNS))%)"
	done
done

#Clerks
NAME=DWs
START=1
END=19
mkdir -p $NAME
echo "-------------------- Clerks (allyes) (DWs) ------------------------------"
for (( i=START; i<=END; i++)) do
	FILE=$NAME/$i"_"$NAME
	echo "Generate "$(($i - $START + 1))"/"$(($END - $START+1))
	java -jar $TOOL gen_clerks -s -c $i -o $FILE

	echo  'Calculate '$FILE
	printf "%*s\r" $COLUMNS "(=0%)"
	for ((j=1; j<=RUNS; j++)) do
		val=""		
		para=""
		if [ $j == 1 ]; then
			val=$FILE"_sizes.txt"
			para=-ob
			echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
		fi
		/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
		rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
		printf "%*s\r" $COLUMNS " (=$(( $j * 100 / $RUNS))%)"
	done
done

NAME=DW
START=1
END=20
mkdir -p $NAME
echo "-------------------- Clerks (all free) (DW) ------------------------------"
for (( i=START; i<=END; i++)) do
	FILE=$NAME/$i"_"$NAME
	echo "Generate "$(($i - $START + 1))"/"$(($END - $START+1))
	java -jar $TOOL gen_clerks -c $i -o $FILE

	echo  'Calculate '$FILE
	printf "%*s\r" $COLUMNS "(=0%)"
	for ((j=1; j<=RUNS; j++)) do
		val=""		
		para=""
		if [ $j == 1 ]; then
			val=$FILE"_sizes.txt"
			para=-ob
			echo "wall time (s), CPU time (s), memory (KB)" > $FILE"_stats_time_mem.txt"
		fi
		/usr/bin/time -f "%e,%U,%M" -o $FILE"_stats_time_mem.txt" -a java -Xmx32G -jar $TOOL bench $para $val -i $FILE".apt" -o $FILE"-strategy"$j -s 1> /dev/null 2> $FILE"_error"$j".txt"
		rc=$?; if [[ $rc != 0 ]]; then echo "not successful"; break 2; fi
		printf "%*s\r" $COLUMNS " (=$(( $j * 100 / $RUNS))%)"
	done
done

